==> alipay-sdk-java-4.35.107.ALL-sources.jar: com/alipay/api/domain/AlipayOpenOperationOpenbizmockSchemaQueryModel.java <==
package com.alipay.api.domain;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;

/**
 * 生成schema测试
 *
 * @author auto create
 * @since 1.0, 2023-01-17 21:28:16
 */
public class AlipayOpenOperationOpenbizmockSchemaQueryModel extends AlipayObject {

	private static final long serialVersionUID = 5734768611243995796L;

	/**
	 * test
	 */
	@ApiField("a")
	private String a;

	/**
	 * test
	 */
	@ApiField("b")
	private String b;

	/**
	 * test
	 */
	@ApiField("c")
	private String c;

	/**
	 * test
	 */
	@ApiField("fuza")
	private TestDemoWzw fuza;

	/**
	 * test
	 */
	@ApiField("id_type")
	private String idType;

	/**
	 * test
	 */
	@ApiField("open_id")
	private String openId;

	/**
	 * test
	 */
	@ApiField("uid")
	private String uid;

	public String getA() {
		return this.a;
	}
	public void setA(String a) {
		this.a = a;
	}

	public String getB() {
		return this.b;
	}
	public void setB(String b) {
		this.b = b;
	}

	public String getC() {
		return this.c;
	}
	public void setC(String c) {
		this.c = c;
	}

	public TestDemoWzw getFuza() {
		return this.fuza;
	}
	public void setFuza(TestDemoWzw fuza) {
		this.fuza = fuza;
	}

	public String getIdType() {
		return this.idType;
	}
	public void setIdType(String idType) {
		this.idType = idType;
	}

	public String getOpenId() {
		return this.openId;
	}
	public void setOpenId(String openId) {
		this.openId = openId;
	}

	public String getUid() {
		return this.uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}

}

==> alipay-sdk-java-4.38.10.ALL-sources.jar: com/alipay/api/domain/AlipayOpenOperationOpenbizmockSchemaQueryModel.java <==
package com.alipay.api.domain;

import com.alipay.api.AlipayObject;
import com.alipay.api.internal.mapping.ApiField;

/**
 * 生成schema测试
 *
 * @author auto create
 * @since 1.0, 2023-07-07 14:40:40
 */
public class AlipayOpenOperationOpenbizmockSchemaQueryModel extends AlipayObject {

	private static final long serialVersionUID = 3144533879919548932L;

	/**
	 * test
	 */
	@ApiField("a")
	private String a;

	/**
	 * test
	 */
	@ApiField("b")
	private String b;

	/**
	 * test
	 */
	@ApiField("c")
	private String c;

	/**
	 * 111
	 */
	@ApiField("complex_a")
	private TestDemo complexA;

	/**
	 * test
	 */
	@ApiField("fuza")
	private TestDemoWzw fuza;

	/**
	 * test
	 */
	@ApiField("id_type")
	private String idType;

	/**
	 * test
	 */
	@ApiField("open_id")
	private String openId;

	/**
	 * {"test":"test"}
	 */
	@ApiField("uid")
	private String uid;

	/**
	 * test
	 */
	@ApiField("uid_a")
	private String uidA;

	public String getA() {
		return this.a;
	}
	public void setA(String a) {
		this.a = a;
	}

	public String getB() {
		return this.b;
	}
	public void setB(String b) {
		this.b = b;
	}

	public String getC() {
		return this.c;
	}
	public void setC(String c) {
		this.c = c;
	}

	public TestDemo getComplexA() {
		return this.complexA;
	}
	public void setComplexA(TestDemo complexA) {
		this.complexA = complexA;
	}

	public TestDemoWzw getFuza() {
		return this.fuza;
	}
	public void setFuza(TestDemoWzw fuza) {
		this.fuza = fuza;
	}

	public String getIdType() {
		return this.idType;
	}
	public void setIdType(String idType) {
		this.idType = idType;
	}

	public String getOpenId() {
		return this.openId;
	}
	public void setOpenId(String openId) {
		this.openId = openId;
	}

	public String getUid() {
		return this.uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}

	public String getUidA() {
		return this.uidA;
	}
	public void setUidA(String uidA) {
		this.uidA = uidA;
	}

}
